#include<string>
#include<vector>
#include<map>
#include<iostream>
#include<boost/numeric/interval.hpp>

#include "TaskList.hh"
#include "TaskListNode.hh"
#include "LightWorldBase.hh"

#ifndef _TIMEPROJECTION_HH_
#define _TIMEPROJECTION_HH_

typedef boost::numeric::interval<double> TInterval;

class TimeProjection {

private:

	TaskList projection;
	std::vector<unsigned long int> projectionOrder;
	std::map<unsigned long int, std::vector<std::string> > precondsReports, effectsReports;
	std::map<unsigned long int, std::pair<double, double> > projectionTimes;
	std::map<double, std::vector<unsigned long int> > taskAtTimeMin;
	std::pair<double, double> findMaxTime(std::vector<TaskListNode*> tln);
	bool canReachTaskFromTo(TaskListNode* t1, TaskListNode* t2);
	bool isCompatible(unsigned long int i1, unsigned long int i2);
	void updateLinksCurrentTask(unsigned long int projID);

public:

	explicit TimeProjection(TaskList const& TL, std::vector<unsigned long int> const& po);
	void updateLinks(LightWorldBase& wb_at_start);
	double totalDuration() const;
	void computeTimeWindows();
	TaskList const& getProjection() const;
	std::pair<double, double> totalDurationWindow() const;
	std::pair<double, double> getTimeWindow(unsigned long int id) const;
	std::vector<double> inactiveDuration(std::vector<unsigned long int> const& actionIDs, double& fromStart, double& toEnd) const;
	bool possibleState(WorldBaseReport const& WBR, LightWorldBase const& wb_at_start, std::vector<double>& durations, bool& atEnd) const;
	std::vector<SocialRuleData*> checkSubList(std::vector<Substitution*> const& vecSub, LightWorldBase const& wb, TaskList const& subTL) const;
	~TimeProjection();

};

inline TimeProjection::TimeProjection(TaskList const& TL, std::vector<unsigned long int> const& po): 
projection(TL), projectionOrder(po) {}

inline TaskList const& TimeProjection::getProjection() const {
	return projection;
}

#endif
