/*
 * Copyright (C) 2007 LAAS/CNRS
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *    - Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *    - Redistributions in binary form must reproduce the above
 *      copyright notice, this list of conditions and the following
 *      disclaimer in the documentation and/or other materials provided
 *      with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT HOLDERS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 */

#if !defined HATP_EXCEPTION_HH_
#define HATP_EXCEPTION_HH_

#include<string>
#include<sstream>

#define ERROR 1
#define WARNING 2

class HATPexception
{
	private:
	/**
	* text of the exception
	*/
	std::string txt;

	/**
	* define the type of the exception (ERROR or WARNING)
	*/
	unsigned int type;


public:
	/**
	* constructor : sets s to txt and i to type
	*/
	explicit HATPexception(unsigned int i, const std::string& s)
	{
		type=i;
		txt=s;
	}

	/**
	* returns txt
	*/
	std::string description()
	{
		std::ostringstream st;
		switch(type)
		{
			case ERROR : st << "ERROR: ";
				     break;
			case WARNING : st << "WARNING: ";
				       break;
		}
		st << txt;

		std::string s(st.str());
		return s;
	}

	/**
	* return type
	*/
	unsigned int getType()
	{
		return type;
	}

	/**
	* destructor : empty
	*/
	~HATPexception()
	{
	}
};

#endif
 
